@@ -40,6 +40,8 @@ def pyhandle_error_handler(func):
 
 
 class BasePidService(metaclass=ABCMeta):
+    service_prefix = "1."
+
     base_url: str
 
     @abstractmethod
@@ -63,10 +65,11 @@ class BasePidService(metaclass=ABCMeta):
         """
         Generates a new PID. Uses a cryptographically secure random, 12 digit
         hexadecimal number separated by hyphens every 4 digits (example: 6ed7-328b-2793)
-        Has been tested to have <1 collisions every 10 million ids.
+        Has been tested to have <1 collisions every 10 million ids. PIDs of the
+        directory are also prefixed with "1.".
         """
         id_ = secrets.token_hex(6)
-        return f"{prefix}/{id_[:4]}-{id_[4:8]}-{id_[8:]}"
+        return f"{prefix}/{BasePidService.service_prefix}{id_[:4]}-{id_[4:8]}-{id_[8:]}"
 
 
 class PidService(BasePidService):
@@ -176,7 +179,7 @@ class PidService(BasePidService):
 class DummyPidService(BasePidService):
     """
     This dummy implementation can be used to test publishing without actually
-    interacting with a Handle server.
+    interacting with a Handle server. It will create fake PIDs.
     """
 
     def __init__(self):
@@ -193,3 +196,22 @@ class DummyPidService(BasePidService):
 
     def set_status(self, pid: str, status: Status):
         pass
+
+
+class NoOpPidService(BasePidService):
+    """
+    The NoOpPidService does completely nothing. It can be used as a feature toggle:
+    using this implementation will turn off all PID features.
+    """
+
+    def reverse_lookup(self, url: str) -> Optional[List[str]]:
+        pass
+
+    def register_pid(self, url: str, name: str) -> str:
+        pass
+
+    def set_name(self, pid: str, new_name: str):
+        pass
+
+    def set_status(self, pid: str, status: Status):
+        pass
