@@ -4,7 +4,12 @@ from unittest.mock import MagicMock
 import pytest
 
 from molgenis.bbmri_eric.errors import EricError
-from molgenis.bbmri_eric.pid_service import DummyPidService, PidService, Status
+from molgenis.bbmri_eric.pid_service import (
+    DummyPidService,
+    NoOpPidService,
+    PidService,
+    Status,
+)
 
 
 @pytest.fixture
@@ -67,7 +72,7 @@ def test_generate_pid(pid_service: PidService):
     pid = pid_service.generate_pid("test")
 
     pid = pid.replace("-", "")
-    prefix, suffix = pid.split("/")
+    prefix, suffix = pid.split("/1.")
 
     assert prefix == "test"
     try:
@@ -79,10 +84,17 @@ def test_generate_pid(pid_service: PidService):
 def test_dummy_service():
     dummy = DummyPidService()
 
-    assert dummy.register_pid("", "").startswith("FAKE-PREFIX/")
+    assert dummy.register_pid("", "").startswith("FAKE-PREFIX/1.")
     assert dummy.reverse_lookup("") is None
 
 
+def test_noop_service():
+    noop = NoOpPidService()
+
+    assert noop.register_pid("", "") is None
+    assert noop.reverse_lookup("") is None
+
+
 def test_base_url(handle_client):
     service1 = PidService(handle_client, "test", "test1.nl")
     service2 = PidService(handle_client, "test", "test2.nl")
